pub type Never = ExecNever;Expand description
An uninhabitable type used to represent impossible values (e.g., in combinators::Void).
Aliased Type
pub struct Never;pub type Never = ExecNever;An uninhabitable type used to represent impossible values (e.g., in combinators::Void).
pub struct Never;